#!/bin/bash
#
# CPAM/ICPAM Pre-Upgrade Check Script
#
# Copyright (c) 2017 Identiv, Inc.
#
# > /opt/cisco/cpam/properties/healthState.txt

RM=/bin/rm
CP=/bin/cp
CHMOD=/bin/chmod
CURL=/usr/bin/curl
MKDIR=/bin/mkdir
KILL=/bin/kill
SUDO=/usr/bin/sudo
DF=/bin/df
PS=/bin/ps
VMSTAT=/usr/bin/vmstat
ZIP=/usr/bin/zip
RPM=/bin/rpm
ECHO=/bin/echo
SERVICE=/sbin/service

# Get standard environment variables
. /opt/cisco/cpam/bin/env.sh cpamupgrade
CURRIDR=`/bin/pwd`

props=/opt/cisco/cpam/properties/cpsm.runtime.properties
pass=`/bin/grep cpsm.runtime.store.local.rootpass $props | /bin/cut -d = -f 2`

$SERVICE mysql start 2>&1 > /dev/null
if [ $? -ne 0 ]; then
	echo "MySQL was not running and failed to start!"
	exit 1
fi

mysqlRootDebug(){
	/usr/bin/mysql -v -u root -p"$pass" vxdb -e "$1"
}

mysqlRoot(){
	/usr/bin/mysql -u root -p"$pass" vxdb -e "$1"
}

mysqlRootNoHeader(){
	/usr/bin/mysql -u root -p"$pass" vxdb --skip-column-names -B -e "$1"
}

#######################################################################################
# migration checklist
#######################################################################################

printf "ICPAM Migration Checklist Addendum\n\n"

date
echo $0

printf "\n\n=== Environment ==="

printf "\n\n### Q1. platform ICPAM is running on:\n\n"

echo "MySql Version"
mysql --version
echo 

echo "# of Processors: "
cat /proc/cpuinfo | grep processor | wc -l
echo 

echo "Memory: "
free -m
echo 

echo "Disk Info"
df -h
echo 

echo "RPM Installed"
rpm -qa cpam
echo
echo

echo "CPAM Backups on System:"
ls -lh /db/cpam-webapp/backup 
echo
echo

printf "\n\n### Q1a. Current Servers: Physical or Virtual?\n\n"

dmesg | grep DMI
dmidecode | grep 'Product Name' | head -1 | sed 's/^[ \t]*//g'

printf "\n\n### Q2. Existing PACS Hardware\n\n"

mysqlRoot "select 'Gateway Controller Modules' as 'Module Type', case when enabled = 1 then 'active' else 'disabled' end as 'enabled?', count(1) as 'Module Count' from vx_dev where dev_type_id = 'GW.MOD' and dev_model_id = 'GW.MtDiabloModel'
group by 1, 2"

mysqlRootNoHeader "select 'Gateway Input Modules' as 'Module Type', case when enabled = 1 then 'active' else 'disabled' end as 'enabled?', count(1) as 'Module Count' from vx_dev where dev_type_id = 'GW.MOD' and dev_model_id = 'GW.MtBearModel'
group by 1, 2"

mysqlRootNoHeader "select 'Gateway Output Modules' as 'Module Type', case when enabled = 1 then 'active' else 'disabled' end as 'enabled?', count(1) as 'Module Count' from vx_dev where dev_type_id = 'GW.MOD' and dev_model_id = 'GW.MtRoseModel'
group by 1, 2"

mysqlRootNoHeader "select 'Gateway Reader Modules' as 'Module Type', case when enabled = 1 then 'active' else 'disabled' end as 'enabled?', count(1) as 'Module Count' from vx_dev where dev_type_id = 'GW.MOD' and dev_model_id = 'GW.MtCoppernicusModel'
group by 1, 2"

mysqlRootNoHeader "select 'EM-100 Door' as 'Module Type', case when enabled = 1 then 'active' else 'disabled' end as 'enabled?', count(1) as 'Module Count' from vx_dev where dev_type_id = 'HV.DOOR'
group by 1, 2"

mysqlRootNoHeader "select 'Mx Door' as 'Module Type', case when enabled = 1 then 'active' else 'disabled' end as 'enabled?', count(1) as 'Module Count' from vx_dev where dev_type_id = 'HH.DOOR' and rel_addr < 9
group by 1, 2"

mysqlRootNoHeader "select 'M64 Controller' as 'Module Type', case when enabled = 1 then 'active' else 'disabled' end as 'enabled?', count(1) as 'Module Count' from vx_dev where dev_model_id = 'HH.MX64_SP'
group by 1, 2"

mysqlRootNoHeader "select 'Mx Expansion Module' as 'Module Type', case when enabled = 1 then 'active' else 'disabled' end as 'enabled?', count(1) as 'Module Count' from vx_dev where dev_type_id in ('HH.ONB_INP', 'HH.ONB_OUT') and dev_model_id like 'HH.EXPBOARD_%' and unid in (select parent from vx_dev)
group by 1, 2"

printf "\n\n### Q3. Number of badges in system:\n\n"

mysqlRootNoHeader "select CONCAT(count(1), ' badges') from vx_badge;"

printf "\n\n### Q4. Number of access policies in system:\n\n"

mysqlRootNoHeader "select CONCAT(count(1), ' CPAM 1.5.3 Access Policies') from gw_vx_access_level;"
mysqlRootNoHeader "select CONCAT(count(1), ' ICPAM 2.x+ Access Policies') from vx_priv_alvl;"

printf "\n\n### Q5. Number of computers running CPAM Client:\n\n"

mysqlRootNoHeader "select concat(count(1), ' workstations') from vx_dev where dev_type_id = 'VX.WKST';"

# printf "\nQ1. Existing number of doors managed by CPAM?\n\n"

#mysqlRootNoHeader "select CONCAT(count(1), ' active Gateway doors') from gw_vx_dev_door and doorstatus <> 'DELETED';"
#mysqlRootNoHeader "select CONCAT(count(1), ' active MX and EM-100 Doors') from vx_dev where vx_dev.dev_type_id like '%DOOR%' and enabled = 1;"

printf "\n\n### Q6. Number of ICPAM administration users?\n\n"

mysqlRootNoHeader "select CONCAT(count(1), ' administration users') from vx_login;"

printf "\n\n=== Software ==="

# printf "\n\n8. Past upgrade history of current CPAM installation(s)"

# printf "#######################################################"

printf "\n\n### Q7. CPAM Software version(s) currently deployed:\n\n"

cat /opt/cisco/cpam/properties/VERSION

printf "\n\n### Q8. Is the base OS 32-bit or 64-bit?\n\n"

uname -a

printf "\n\n### Q9. Which active licenses are currently applied on the end-system?\n\n" 

curl http://127.0.0.1:9091/cisco_debug_page.html 2>&1 | grep -e 'EAI' -e HA -e BDE -e AGWM -e WSAPI | awk -F, '{printf "%s\t%s\n",$1,$2}'

echo

mysqlRootNoHeader "select license from gw_vx_lic;" | while read lic; do printf "$lic\n\n" | sed 's/{{{\([^}]*\)}}}/\1/g'; done;

printf "\n### Q10. Do you utilize more than one reader module per door?\n\n"

mysqlRoot "select count(1) as '2nd Reader Use', dev_type_id as 'Type' from vx_dev
where (dev_type_id = 'HV.RDR' and rel_addr = 2)
or (dev_type_id like 'HH.RDR' and rel_addr > 8)
or (dev_type_id = 'GW.MOD' and dev_model_id = 'GW.MtCoppernicusModel')
group by 2"

printf "\n\n=== Integrations ==="

printf "\n\n### Q11. VSM 6 Driver: "
mysqlRootNoHeader "select count(*) as 'VSM 6 Driver' from cb_bwcam_vx_dev_driver;"

printf "\n### Q12. VSM 7 Driver: "
mysqlRootNoHeader "select count(*) as 'VSM 7 Driver' from cb_bwcam_vx_dev_driver7x;"

# mysqlRoot "SELECT dev_type_id FROM vx_dev where dev_type_id = 'CB.DRIVER'"

printf "\n### Q13. Cisco Unified Call Manager: "

grep 'GET /IPPhoneManager.jsp' /opt/cisco/cpam/apache-tomcat/logs/localhost_access_log.txt 2>&1 > /dev/null
rc=$?
if [ "$rc" -eq 0 ]; then
	printf "CUCM/IPPhoneManager is actively in-use\n"
else
	printf "CUCM/IPPhoneManager is not recently in-use\n"
fi

printf "\n### Q14. CPAM/ICPAM Web Service API: "
#If the WebService is Enabled then it is deployed in /opt/cisco/cpam/apache-tomcat/webapps/
ls /opt/cisco/cpam/apache-tomcat/webapps/acws.war 2>&1 > /dev/null
rc1=$?
grep 'Payload: .*"http://cisco.com/physec/acws/"' /opt/cisco/cpam/apache-tomcat/logs/catalina.out 2>&1 > /dev/null
rc2=$?
if [ "$rc2" -eq 0 -a "$rc1" -eq 0 ]; then
	printf "ACWS web service is actively in-use\n"
else
	if [ "$rc1" -ne 0 ]; then
		printf "ACWS web service not deployed\n"
	else
		printf "ACWS web service deployed but not actively used\n"
	fi
fi

printf "\n### Q15. EDI Integration: \n\n"

mysqlRoot "SELECT count(1) as "Personnel EDI Project" FROM gw_vx_edi_manager where schedule_status='STARTED' and proj_type='PERSONNEL'"
mysqlRoot "SELECT count(1) as "Badge EDI Project" FROM gw_vx_edi_manager where schedule_status='STARTED' and proj_type='BADGE'"
 
printf "\n\n=== Customization and Patches ==="

printf "\n\n### Q16. EDI extension(s): \n\n"
# Extension jar files are deployed in /opt/cisco/cpam/eaicfg folder on the CPAM/ICPAM server
ls '/opt/cisco/cpam/eaicfg/*.jar' > /dev/null 2>&1
if [ "$?" -eq 0 ]; then
	ls -l '/opt/cisco/cpam/eaicfg/*.jar'
else
	printf "none EDI custom jars\n"
fi
 
printf "\n\n### Q17. Custom DB views: ?"
mysqlRoot "SHOW FULL TABLES IN vxdb WHERE TABLE_TYPE LIKE 'VIEW'"

printf "\n\n=== Database Related ==="

printf "\n\n\n### Q18. Event Archival\n\n"

mysqlRootNoHeader "select CONCAT(count(1), ' unarchived events') from vx_evt;"
mysqlRootNoHeader "select CONCAT(count(1), ' archived events') from vx_flat_evt;" 

##########################################################################

printf "\n\n### Q19. DB Collations in use?\n\n"

mysqlRootNoHeader "select TABLE_COLLATION from information_schema.tables where TABLE_SCHEMA = 'vxdb' group by 1"

printf "\n=== COMPLETE ==="

exit 0
